/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.scripting.jython.grizzly;

import java.io.PrintWriter;

public class WSGIBodyWriter implements BodyWriter{

    /* From the WSGI spec
        New WSGI applications and frameworks should not use the write() callable if it is possible to avoid doing so.
        The write() callable is strictly a hack to support imperative streaming APIs.
        In general, applications should produce their output via their returned iterable,
        as this makes it possible for web servers to interleave other tasks in the same Python thread,
        potentially providing better throughput for the server as a whole.

       The write() callable is returned by the start_response() callable, and it accepts a single parameter:
       a string to be written as part of the HTTP response body,
       that is treated exactly as though it had been yielded by the output iterable.
       In other words, before write() returns, it must guarantee that the passed-in string was either completely sent to the client,
       or that it is buffered for transmission while the application proceeds onward.
    */
    private PrintWriter myWriter;
    public void __call__(String body) {
        myWriter.write(body);
    }
    public WSGIBodyWriter(PrintWriter p) {
        myWriter = p;
    }
}
